about summary refs log tree commit diff
path: root/nixpkgs/pkgs/applications/networking/kubo-migrator
diff options
context:
space:
mode:
Diffstat (limited to 'nixpkgs/pkgs/applications/networking/kubo-migrator')
-rw-r--r--nixpkgs/pkgs/applications/networking/kubo-migrator/all-migrations.nix4
-rw-r--r--nixpkgs/pkgs/applications/networking/kubo-migrator/unwrapped.nix6
2 files changed, 6 insertions, 4 deletions
diff --git a/nixpkgs/pkgs/applications/networking/kubo-migrator/all-migrations.nix b/nixpkgs/pkgs/applications/networking/kubo-migrator/all-migrations.nix
index 8cdeb3efb8ea..54ae2551caa3 100644
--- a/nixpkgs/pkgs/applications/networking/kubo-migrator/all-migrations.nix
+++ b/nixpkgs/pkgs/applications/networking/kubo-migrator/all-migrations.nix
@@ -36,8 +36,9 @@ let
   };
 
   # Concatenation of the latest repo version and the version of that migration
-  version = "14.1.0.0";
+  version = "15.1.0.1";
 
+  fs-repo-14-to-15 = fs-repo-common "fs-repo-14-to-15" "1.0.1";
   fs-repo-13-to-14 = fs-repo-common "fs-repo-13-to-14" "1.0.0";
   fs-repo-12-to-13 = fs-repo-common "fs-repo-12-to-13" "1.0.0";
   fs-repo-11-to-12 = fs-repo-common "fs-repo-11-to-12" "1.0.2";
@@ -54,6 +55,7 @@ let
   fs-repo-0-to-1   = fs-repo-common "fs-repo-0-to-1"   "1.0.1";
 
   all-migrations = [
+    fs-repo-14-to-15
     fs-repo-13-to-14
     fs-repo-12-to-13
     fs-repo-11-to-12
diff --git a/nixpkgs/pkgs/applications/networking/kubo-migrator/unwrapped.nix b/nixpkgs/pkgs/applications/networking/kubo-migrator/unwrapped.nix
index d5dc1421a58a..1e63c5852ca3 100644
--- a/nixpkgs/pkgs/applications/networking/kubo-migrator/unwrapped.nix
+++ b/nixpkgs/pkgs/applications/networking/kubo-migrator/unwrapped.nix
@@ -11,12 +11,12 @@ buildGoModule rec {
     owner = "ipfs";
     repo = "fs-repo-migrations";
     # Use the latest git tag here, since v2.0.2 does not
     # contain the latest migration fs-repo-13-to-14/v1.0.0
     # The fs-repo-migrations code itself is the same between
     # the two versions but the migration code, which is built
     # into separate binaries, is not.
-    rev = "fs-repo-13-to-14/v1.0.0";
-    hash = "sha256-y0IYSKKZlFbPrTUC6XqYKhS3a79rieNGBL58teWMlC4=";
+    rev = "fs-repo-14-to-15/v1.0.1";
+    hash = "sha256-oIGDZr0cv+TIl5glHr3U+eIqAlPAOWyFzgfQGGM+xNM=";
   };
 
   sourceRoot = "${src.name}/fs-repo-migrations";
@@ -11,12 +11,12 @@ buildGoModule rec {
     repo = "fs-repo-migrations";
     # Use the latest git tag here, since v2.0.2 does not
-    # contain the latest migration fs-repo-13-to-14/v1.0.0
+    # contain the latest migration fs-repo-14-to-15/v1.0.1
     # The fs-repo-migrations code itself is the same between
     # the two versions but the migration code, which is built